@@ -1,5 +1,6 @@
 """Models of Zinnia CMS Plugins"""
 from django.db import models
+from django.utils import six
 from django.utils.translation import ugettext_lazy as _
 from django.utils.encoding import python_2_unicode_compatible
 
@@ -23,8 +24,8 @@ class LatestEntriesPlugin(CMSPlugin):
     featured = models.NullBooleanField(
         _('featured'),
         blank=True, null=True,
-        choices=((True, _('Yes')),
-                 (False, _('No'))))
+        choices=((True, _('Show featured entries only')),
+                 (False, _('Hide featured entries'))))
     categories = models.ManyToManyField(
         'zinnia.Category', verbose_name=_('categories'),
         blank=True, null=True)
@@ -43,7 +44,7 @@ class LatestEntriesPlugin(CMSPlugin):
         help_text=_('0 means all the entries'))
     offset = models.PositiveIntegerField(
         _('offset'), default=0,
-        help_text=_('offset used to display entries'))
+        help_text=_('number of entries to skip from top of list'))
     template_to_render = models.CharField(
         _('template'), blank=True,
         max_length=250, choices=TEMPLATES,
@@ -161,7 +162,7 @@ class CalendarEntriesPlugin(CMSPlugin):
     month = models.PositiveIntegerField(_('month'), null=True, blank=True)
 
     def __str__(self):
-        name = _('Calendar entries')
+        name = six.text_type(_('Calendar entries'))
         if self.year:
-            name = u'%s: %s/%s' % (name, self.year, self.month)
-        return u'%s' % name
+            name = '%s: %s/%s' % (name, self.year, self.month)
+        return name
